@@ -2,7 +2,7 @@ use strict;
 use warnings;
 
 ### after: use lib qw(@RT_LIB_PATH@);
-use lib qw(/Users/falcone/work/rt/4.2/local/lib /Users/falcone/work/rt/4.2//lib);
+use lib qw(/opt/rt4/local/lib /opt/rt4/lib);
 
 package RT::Extension::MandatoryOnTransition::Test;
 
